@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /*
  * DOSEMU debugger,  1995 Max Parke <mhp@light.lightlink.com>
  *
@@ -26,7 +32,7 @@
 #include <sys/ioctl.h>
 
 #define    TMPFILE_		"/var/run/dosemu."
-#define    TMPFILE_HOME		".dosemu/dosemu."
+#define    TMPFILE_HOME		".dosemu/run/dosemu."
 #define    TMPFILE               dosemu_tmpfile_path 
 static char dosemu_tmpfile_path[256];
 
