@@ -1,3 +1,10 @@
+/* 
+ * All modifications in this file to the original code are
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /*
  * DOSEMU debugger,  1995 Max Parke <mhp@light.lightlink.com>
  *
@@ -59,12 +66,6 @@
 #define MHP_PRIVATE
 #include "mhpdbg.h"
 
-#ifndef MAP_LOC
-  #define MAP_LOC		"/usr/src/dosemu/bin/dosemu.map"
-#endif
-
-char dosemu_map_file_name[256] = MAP_LOC;
-
 #define makeaddr(x,y) ((((unsigned long)x) << 4) + (unsigned long)y)
 
 #if 0 /* modify_ldt already defined in dpmi.c */
@@ -391,12 +392,12 @@ static void mhp_rmapfile(int argc, char *argv[])
   unsigned char bytebuf[IBUFS];
   unsigned long a1;
 
-  ifp = fopen(dosemu_map_file_name, "r");
+  ifp = fopen(DOSEMU_MAP_PATH, "r");
   if (!ifp) {
-     mhp_printf("unable to open map file\n");
+     mhp_printf("unable to open map file %s\n", DOSEMU_MAP_PATH);
      return;
   }
-  mhp_printf("Reading map file\n");
+  mhp_printf("Reading map file %s\n", DOSEMU_MAP_PATH);
   last_symbol = 0;
   while (last_symbol < MAXSYM) {
      if(!fgets(bytebuf, 100, ifp))
@@ -1325,11 +1326,7 @@ static void mhp_regs(int argc, char * argv[])
 
  if (!traceloop)
   mhp_printf( "system state: %s%s%s%s\n",
-#ifdef X86_EMULATOR
-       config.cpuemu > 1 ? "emulated," : "",
-#else
        "",
-#endif
        mhpdbgc.stopped ? "stopped" : "running",
        IN_DPMI ? " in DPMI" : (in_dpmi?" in real mode while in DPMI":""),
        IN_DPMI ?(dpmi_mhp_getcsdefault()?"-32bit":"-16bit") : "");
