@@ -1,3 +1,10 @@
+/* 
+ * All modifications in this file to the original code are
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* Copyright 1995  Joel N. Weber II
    See the file README.sound in this directory for more information */
 
@@ -582,7 +589,7 @@ void linux_mpu401_data_write(__u8 data)
 	if (mpu_fd == -1) {
 	  	if (mpu_disabled) return;
 		/* Added NONBLOCK to prevent hanging - Karcher */
-		mpu_fd = open("/var/run/dosemu-midi", 
+		mpu_fd = open(DOSEMU_MIDI_PATH,
 			      O_WRONLY | O_CREAT | O_NONBLOCK, 0777);
 		if (mpu_fd == -1) {
 			mpu_disabled = TRUE;
