@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* dynamic debug handlers - by Tim Bird */
 /* modified to support debug levels -- peak */
 #include "config.h"
@@ -59,9 +65,6 @@ GetDebugFlagsHelper(char *debugStr, int print)
   debugStr[i++] = DebugFlag(d.pd);       debugStr[i++] = 'P';
   debugStr[i++] = DebugFlag(d.request);  debugStr[i++] = 'r';
   debugStr[i++] = DebugFlag(d.sound);    debugStr[i++] = 'S';
-#ifdef X86_EMULATOR
-  debugStr[i++] = DebugFlag(d.emu);      debugStr[i++] = 'e';
-#endif
 
   debugStr[i] = 0;
   if (print) dbug_printf("debugStr is %s\n", debugStr);
