@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* 
  * DANG_BEGIN_MODULE
  *
@@ -42,6 +48,7 @@
 #include "memory.h"
 #include "bios.h"
 #include "vc.h"
+#include "speaker.h"
 
 #if X_GRAPHICS
 #include "X.h"
@@ -692,8 +699,13 @@ void int10()
       CARRY;
       return;
     }
-    if (x >= co || y >= li)
-      break;
+    if (x >= co || y >= li) {
+      /* some apps use this to hide the cursor,
+       * we move it 1 char behind the visible part
+       */
+      x = co;
+      y = li -1;
+    }
 
     set_bios_cursor_x_position(page, x);
     set_bios_cursor_y_position(page, y);
