@@ -1,10 +1,12 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 #define EXTERN 
 #define INIT(x...)		=  ## x
 
-#ifndef lint
-static char *id= "$Id: data.c,v 1.4 1995/04/08 22:29:37 root Exp $";
-#endif
-
 #include <termios.h>
 #include <sys/types.h>
 #include "config.h"
