@@ -1,8 +1,13 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 #include <stdlib.h>
 #include <unistd.h>
 #include "emu.h"
 #include "priv.h"
-#include "lt-threads.h"
 
 #if 0
 #define PRIV_TESTING
@@ -11,15 +16,8 @@
 /* Some handy information to have around */
 static uid_t uid,euid;
 static gid_t gid,egid;
-#ifndef USE_THREADS
 static uid_t cur_uid, cur_euid;
 static gid_t cur_gid, cur_egid;
-#else
-#define cur_uid  (OWN_TCB->uid)
-#define cur_euid (OWN_TCB->euid)
-#define cur_gid  (OWN_TCB->gid)
-#define cur_egid (OWN_TCB->egid)
-#endif
 
 static int skip_priv_setting = 0;
 
@@ -224,7 +222,8 @@ void priv_init(void)
   uid  = cur_uid  = getuid();
   if (!uid) under_root_login =1;
   euid = cur_euid = geteuid();
-  if (!euid) can_do_root_stuff = skip_priv_setting = 1;
+  if (!euid) can_do_root_stuff = 1;
+  if (!uid) skip_priv_setting = 1;
   gid  = cur_gid  = getgid();
   egid = cur_egid = getegid();
 
