@@ -1,8 +1,15 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* 
  * Various sundry utilites for dos emulator.
  *
  */
 #include <stdio.h>
+#include <stdlib.h>
 #include <stdarg.h>
 #include <malloc.h>
 #include <sys/time.h>
@@ -20,9 +27,6 @@
 #include "pic.h"
 #include "dpmi.h"
 #include "utilities.h"
-#ifdef USE_THREADS
-#include "lt-threads.h"
-#endif
 #ifdef USE_MHPDBG
 #include "mhpdbg.h"
 #endif
@@ -60,14 +64,8 @@ static char *timestamp (char *p)
   unsigned long t;
   int i;
 
-#ifdef X86_EMULATOR
-  if ((config.cpuemu>1) && in_vm86) t=0; else
-#endif
   t = GETusTIME(0)/1000;
   /* [12345678]s - SYS time */
-#ifdef X86_EMULATOR
-    if ((config.cpuemu>1) && in_vm86) strcpy(p,"[********] "); else
-#endif
     {
       p[0] = '[';
       for (i=8; i>0; --i)
@@ -149,9 +147,6 @@ int vlog_printf(int flg, const char *fmt, va_list args)
 #endif
      ) return 0;
 
-#ifdef USE_THREADS
-  lock_resource(resource_libc);
-#endif
   {
     char *q;
 
@@ -182,9 +177,6 @@ int vlog_printf(int flg, const char *fmt, va_list args)
       }
     }
   }
-#ifdef USE_THREADS
-  unlock_resource(resource_libc);
-#endif
   return i;
 }
 
@@ -368,3 +360,59 @@ int exists_file(char *name)
 	return (S_ISREG(st.st_mode));
 }
 
+char *strcatdup(char *s1, char *s2)
+{
+	char *s;
+	if (!s1 || !s2) return 0;
+	s = malloc(strlen(s1)+strlen(s2)+1);
+	if (!s) return 0;
+	strcpy(s,s1);
+	return strcat(s,s2);
+}
+
+char *assemble_path(char *dir, char *file, int append_pid)
+{
+	char *s;
+	char pid[32] = "";
+	if (append_pid) sprintf(pid, "%d", getpid());
+	s = malloc(strlen(dir)+1+strlen(file)+strlen(pid)+1);
+	if (!s) {
+		fprintf(stderr, "out of memory, giving up\n");
+		exit(1);
+	}
+	sprintf(s, "%s/%s%s", dir, file, pid);
+	return s;
+}
+
+char *mkdir_under(char *basedir, char *dir, int append_pid)
+{
+	char *s = basedir;
+
+	if (dir) s = assemble_path(basedir, dir, append_pid);
+	if (!exists_dir(s)) {
+		if (mkdir(s, S_IRWXU)) {
+			fprintf(stderr, "can't create local %s directory, giving up\n", s);
+			exit(1);
+		}
+	}
+	return s;
+}
+
+char *get_path_in_HOME(char *path)
+{
+	char *home = getenv("HOME");
+
+	if (!home) {
+		fprintf(stderr, "odd environment, you don't have $HOME, giving up\n");
+		exit(1);
+	}
+	if (!path) {
+		return strdup(home);
+	}
+	return assemble_path(home, path, 0);
+}
+
+char *get_dosemu_local_home(void)
+{
+	return mkdir_under(get_path_in_HOME(".dosemu"), 0, 0);
+}
