@@ -1,3 +1,10 @@
+/* 
+ * All modifications in this file to the original code are
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* ipx.c for the DOS emulator
  * 		Tim Bird, tbird@novell.com
  *
@@ -120,7 +127,7 @@ InitIPXFarCallHelper(void)
     n_printf("IPX: trying to read network and node address from DOS.INI\n");
     
     /* take some time here to read my address from the DOS.INI file */
-    GetValueFromIniFile( "/etc/dosemu/dos.ini", "ipx", "network", value );
+    GetValueFromIniFile(IPX_DOS_INI_PATH, "ipx", "network", value );
     if( strlen( value )==0 ) {
       n_printf("IPX: cannot read IPX network address from dos.ini file\n");
       n_printf("IPX: please create an [IPX] section in your dos.ini file\n");
@@ -142,7 +149,7 @@ InitIPXFarCallHelper(void)
       }
     }
     
-    GetValueFromIniFile( "/etc/dosemu/dos.ini", "ipx", "node", value );
+    GetValueFromIniFile(IPX_DOS_INI_PATH, "ipx", "node", value );
     if( strlen( value )==0 ) {
       n_printf("IPX: cannot read IPX node address from dos.ini file\n");
     } else {
