@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /*
  * SIDOC_BEGIN_MODULE
  *
@@ -290,9 +296,6 @@ int bogospeed(unsigned long *spus, unsigned long *sptick)
 	/* speed division factor to get 838ns from CPU clocks */
 	*sptick = (LLF_TICKS*mlt)/dvs;
 
-#ifdef X86_EMULATOR
-	config.emuspeed = dvs/mlt;
-#endif
 	fprintf (stderr,"CPU speed set to %d/%d MHz\n",dvs,mlt);
 	first = 0;
 	return 0;
