@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /*
  * Extensions by Robert Sanders, 1992-93
  * 
@@ -129,6 +135,8 @@ __asm__("___START___: jmp _emulate\n");
 #include <setjmp.h>
 #endif
 #include "speaker.h"
+#include "utilities.h"
+#include "dos2linux.h"
 
 #include "keyb_clients.h"
 
@@ -138,7 +146,6 @@ __asm__("___START___: jmp _emulate\n");
 
 extern void     stdio_init(void);
 extern void     time_setting_init(void);
-extern void     tmpdir_init(void);
 extern void     low_mem_init(void);
 
 extern void     shared_memory_exit(void);
@@ -152,11 +159,6 @@ extern void     print_version(void);
 
 extern void io_select_init(void);
 
-#ifdef USE_THREADS
-extern void treads_init(void);
-#endif
-
-
 
 void 
 boot(void)
@@ -323,7 +325,6 @@ module_init(void)
     vm86plus_init();		/* emumodule support */
     SIG_init();			/* silly int generator support */
     memcheck_init();		/* lower 1M memory map support */
-    tmpdir_init();		/* create our temporary dir */
 }
 
 #ifdef __NetBSD__
@@ -383,20 +384,13 @@ void
 emulate(int argc, char **argv)
 #endif
 {
+    extern void parse_dosemu_users(void);
 #ifdef __NetBSD__
     changesegs();
 #endif
 
     srand(time(NULL));
 
-#ifdef USE_THREADS
-    treads_init();		/* init the threads system,
-				 * after this we will be thread0.
-				 * Because treads_init() captures SIGTERM
-				 * and signal_init() also does it,
-				 * we capture it via 'exit'.
-    				 */
-#endif
     /* NOW! it is safe to touch the priv code.  */
     priv_init();  /* This must come first! */
 
@@ -427,9 +421,7 @@ emulate(int argc, char **argv)
     cpu_setup();		/* setup the CPU */
     pci_setup();
     hardware_setup();		/* setup any hardware */
-#ifdef NEW_PORT_CODE
     extra_port_init();		/* setup ports dependent on config */
-#endif
     memory_init();		/* initialize the memory contents */
     boot();			/* read the boot sector & get moving */
 
@@ -565,9 +557,6 @@ leavedos(int sig)
       mhp_exit_intercept(sig);
     }
 
-    /* remove tmpdir */
-    rmdir(tmpdir);
-
     itv.it_interval.tv_sec = itv.it_interval.tv_usec = 0;
     itv.it_value = itv.it_interval;
     if (setitimer(TIMER_TIME, &itv, NULL) == -1) {
@@ -642,14 +631,14 @@ leavedos(int sig)
 	disallocate_vt();
     }
     flush_log();
-#ifdef USE_THREADS
+
+    /* remove per process tmpdir and its contents */
     {
-	extern void Exit(int status);
-	Exit(sig);
+       char *command = strcatdup("rm -rf >/dev/null 2>&1 ", TMPDIR_PROCESS);
+       if (command) run_unix_command(command); /* beware of system() !! */
     }
-#else
+
     _exit(sig);
-#endif
 }
 
 #if 0
