@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* 
  * DANG_BEGIN_MODULE
  *
@@ -100,7 +106,7 @@
  *
  * 1998/02/22: Rework of mouse support in graphics modes; put in some
  * code to enable mouse grabbing. Can be activated via Ctrl+Alt+<some configurable key>;
- * default is "Home". (the code needs to be enabled via NEW_X_MOUSE)
+ * default is "Home".
  * -- sw
  *
  * 1998/03/08: Further work at mouse support in graphics modes.
@@ -114,6 +120,8 @@
  * 1998/04/05: We are using backing store now in text modes.
  * -- sw
  *
+ * 1998/05/28: some re-arangements of the mouse code.
+ * -- EB
  *
  * DANG_END_CHANGELOG
  */
@@ -130,15 +138,7 @@
 
 #undef DEBUG_MOUSE_POS			/* show X mouse in graphics modes */
 
-#ifndef NEW_X_MOUSE
-  #undef ENABLE_POINTER_GRAB		/* when defined, F12 toggles grabbing of all key & mouse events */
-  #ifdef ENABLE_POINTER_GRAB
-  #define MOUSE_SCALE_X 2			/* scale mouse movements reported to dosemu; */
-  #define MOUSE_SCALE_Y 2			/* undefine MOUSE_SCALE_X to restore old behavior */
-  #endif
-#else /* NEW_X_MOUSE */
-  #undef ENABLE_KEYBOARD_GRAB		/* when grabbing all mouse events, grab keyboard too */
-#endif /* NEW_X_MOUSE */
+#undef ENABLE_KEYBOARD_GRAB		/* when grabbing all mouse events, grab keyboard too */
 
 /* define if you wish to have a visual indication of the area being updated */
 #undef DEBUG_SHOW_UPDATE_AREA
@@ -155,9 +155,7 @@
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 #include <X11/cursorfont.h>
-#ifdef NEW_X_MOUSE
 #include <X11/keysym.h>
-#endif /* NEW_X_MOUSE */
 #include <sys/mman.h>           /* root@sjoerd:for mprotect*/
 
 #include "emu.h"
@@ -200,9 +198,9 @@
 static const u_char dos_to_latin[]={
    0xc7, 0xfc, 0xe9, 0xe2, 0xe4, 0xe0, 0xe5, 0xe7,  /* 80-87 */ 
    0xea, 0xeb, 0xe8, 0xef, 0xee, 0xec, 0xc4, 0xc5,  /* 88-8F */
-   0xc9, 0xe6, 0xc6, 0xf4, 0xf6, 0xf3, 0xfb, 0xf9,  /* 90-97 */
+   0xc9, 0xe6, 0xc6, 0xf4, 0xf6, 0xf2, 0xfb, 0xf9,  /* 90-97 */
    0xff, 0xd6, 0xdc, 0xa2, 0xa3, 0xa5, 0x00, 0x00,  /* 98-9F */
-   0xe1, 0xed, 0xf2, 0xfa, 0xf1, 0xd1, 0xaa, 0xba,  /* A0-A7 */
+   0xe1, 0xed, 0xf3, 0xfa, 0xf1, 0xd1, 0xaa, 0xba,  /* A0-A7 */
    0xbf, 0x00, 0xac, 0xbd, 0xbc, 0xa1, 0xab, 0xbb,  /* A8-AF */
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  /* B0-B7 */
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  /* B8-BF */
@@ -216,6 +214,47 @@ static const u_char dos_to_latin[]={
    0xb0, 0xb7, 0x00, 0x00, 0xb3, 0xb2, 0x00, 0x00   /* F8-FF */
 };  
 
+static const u_char dos_to_latin1[]={
+   0xc7, 0xfc, 0xe9, 0xe2, 0xe4, 0xe0, 0xe5, 0xe7,  /* 80-87 */
+   0xea, 0xeb, 0xe8, 0xef, 0xee, 0xec, 0xc4, 0xc5,  /* 88-8F */
+   0xc9, 0xe6, 0xc6, 0xf4, 0xf6, 0xf2, 0xfb, 0xf9,  /* 90-97 */
+   0xff, 0xd6, 0xdc, 0xa2, 0xa3, 0xd8, 0xd7, 0x00,  /* 98-9F */
+   0xe1, 0xed, 0xf3, 0xfa, 0xf1, 0xd1, 0xaa, 0xba,  /* A0-A7 */
+   0xbf, 0xae, 0xac, 0xbd, 0xbc, 0xa1, 0xab, 0xbb,  /* A8-AF */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0xc1, 0xc2, 0xc0,  /* B0-B7 */
+   0xa9, 0x00, 0x00, 0x00, 0x00, 0xa2, 0xa5, 0xac,  /* B8-BF */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe3, 0xc3,  /* C0-C7 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xa4,  /* C8-CF */
+   0xf0, 0xd0, 0xca, 0xcb, 0xc8, 0x00, 0xcd, 0xce,  /* D0-D7 */
+   0xcf, 0x00, 0x00, 0x00, 0x00, 0xa6, 0xcc, 0x00,  /* D8-DF */
+   0xd3, 0xdf, 0xd4, 0xd2, 0xf5, 0xe5, 0xb5, 0xdc,  /* E0-E7 */
+   0xfc, 0xda, 0xdb, 0xd9, 0xfd, 0xdd, 0xad, 0xb4,  /* E8-EF */
+   0xad, 0xb1, 0x00, 0xbe, 0xb6, 0xa7, 0xf7, 0xb8,  /* F0-F7 */
+   0xb0, 0xa8, 0xb7, 0xb9, 0xb3, 0xb2, 0x00, 0xa0   /* F8-FF */
+};
+
+static const u_char dos_to_latin2[]={
+   0xc7, 0xfc, 0xe9, 0xe2, 0xe4, 0xf9, 0xe6, 0xe7,  /* 80-87 */
+   0xb3, 0xeb, 0xf5, 0xd5, 0xee, 0xac, 0xc4, 0xc6,  /* 88-8F */
+   0xc9, 0xc5, 0xe5, 0xf4, 0xf6, 0xa5, 0xb5, 0xa6,  /* 90-97 */
+   0xb6, 0xd6, 0xdc, 0xab, 0xbb, 0xa3, 0xd7, 0xe8,  /* 98-9F */
+   0xe1, 0xed, 0xf3, 0xfa, 0xa1, 0xb1, 0xae, 0xbe,  /* A0-A7 */
+   0xca, 0xea, 0x00, 0xbc, 0xc8, 0xba, 0xab, 0xbb,  /* A8-AF */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0xc1, 0xc2, 0xcc,  /* B0-B7 */
+   0xaa, 0x00, 0x00, 0x00, 0x00, 0xaf, 0xbf, 0x00,  /* B8-BF */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc3, 0xe3,  /* C0-C7 */
+   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xa4,  /* C8-CF */
+   0xf0, 0xd0, 0xcf, 0xcb, 0xef, 0xd2, 0xcd, 0xce,  /* D0-D7 */
+   0xec, 0x00, 0x00, 0x00, 0x00, 0xde, 0xd9, 0x00,  /* D8-DF */
+   0xd3, 0xdf, 0xd4, 0xd1, 0xf1, 0xf2, 0xa9, 0xb9,  /* E0-E7 */
+   0xc0, 0xda, 0xe0, 0xdb, 0xfd, 0xdd, 0xfe, 0xb4,  /* E8-EF */
+   0xad, 0xbd, 0xb2, 0xb7, 0xa2, 0xa7, 0xf7, 0xb8,  /* F0-F7 */
+   0xb0, 0xa8, 0xff, 0xfb, 0xd8, 0xf8, 0x00, 0xa0   /* F8-FF */
+};
+
+extern int dosemu_argc;
+extern char **dosemu_argv;
+
 /**************************************************************************/
 
 /* From Xkeyb.c */
@@ -318,16 +357,10 @@ static vga_emu_update_type veut;
 static int remap_src_modes = 0;
 static vgaemu_display_type X_screen;
 
-#ifndef NEW_X_MOUSE
-#ifdef ENABLE_POINTER_GRAB
-static int grab_active = 0;
-#endif
-#else /* NEW_X_MOUSE */
 static int grab_active = 0;
 static char *grab_keystring = "Home";
 static int grab_keysym = NoSymbol;
 static int mouse_x = 0, mouse_y = 0;
-#endif /* NEW_X_MOUSE */
 
 static int X_map_mode = -1;
 static int X_unmap_mode = -1;
@@ -1099,6 +1132,7 @@ int X_init(void)
 {
   XGCValues gcv;
   XClassHint xch;
+  XWMHints wmhint;
   XSetWindowAttributes attr;
   char *display_name; 
 
@@ -1177,7 +1211,11 @@ int X_init(void)
   XSetIconName(display, mainwindow, config.X_icon_name);
   xch.res_name  = "XDosEmu";
   xch.res_class = "XDosEmu";
-  XSetClassHint(display, mainwindow, &xch);
+
+  wmhint.window_group = mainwindow;
+  wmhint.flags = WindowGroupHint;
+  XSetWMProperties(display, mainwindow, NULL, NULL, 
+    dosemu_argv, dosemu_argc, NULL, &wmhint, &xch);
 
 #if CONFIG_X_SELECTION
   /* Get atom for COMPOUND_TEXT type. */
@@ -1224,7 +1262,6 @@ int X_init(void)
     leavedos(99);
   }
 
-#ifdef NEW_X_MOUSE
   if(config.X_mgrab_key) grab_keystring = config.X_mgrab_key;
   if(*grab_keystring) grab_keysym = XStringToKeysym(grab_keystring);
   if(grab_keysym != NoSymbol) {
@@ -1233,7 +1270,6 @@ int X_init(void)
   else {
     X_printf("X: X_init: mouse grabbing disabled\n");
   }
-#endif /* NEW_X_MOUSE */
 
   /* HACK!!! Don't konw is video_mode is already set */
   X_setmode(TEXT, co, li);
@@ -1352,9 +1388,7 @@ static int X_setmode(int mode_class, int text_width, int text_height)
 
   destroy_ximage();
 
-#ifdef NEW_X_MOUSE
   mouse_x = mouse_y = 0;
-#endif /* NEW_X_MOUSE */
 
   switch(vga.mode_class) {
 
@@ -1790,12 +1824,7 @@ void X_redraw_screen(void)
 
   refresh_palette();
 
-  switch(video_mode)
-    {
-    case 0x00:
-    case 0x01:
-    case 0x02:
-    case 0x03:
+  if (vga.mode_class==TEXT) {
       for(y = 0; (y < li); y++) 
 	{
 	  x=0;
@@ -1826,13 +1855,10 @@ void X_redraw_screen(void)
 	    } 
 	  while(x<co);
 	}
-      break;
-
-     
-    default:
-      X_printf("X_redraw_screen:No valid video mode\n");
-      break;
-    }
+  }
+  else {
+      X_printf("X_redraw_screen: Should not be here, Text refresh in graphics video mode\n");
+  }
 
   prev_cursor_shape = NO_CURSOR;   /* was overwritten */
   redraw_cursor();
@@ -2212,153 +2238,40 @@ void X_change_mouse_cursor(void)
  */ 
 static void set_mouse_position(int x, int y)
 {
-#ifndef NEW_X_MOUSE
-  int dx = x - mouse.x;
-  int dy = y - mouse.y;
-  
-  switch(video_mode)	/* only a conversion when in text-mode*/
-    {
-    case 0x00:
-    case 0x01:
-    case 0x02:
-    case 0x03:
-      /* XXX - this works in text mode only */
-      x = x*8/font_width;
-      y = y*8/font_height;
-      dx = ((x-mouse.x)*font_width)>>3;
-      dy = ((y-mouse.y)*font_height)>>3;
-      break;
-    case 0x0d:
-    case 0x0e:
-    case 0x10:
-    case 0x12:
-    case 0x13:
-    case 0x5c: /* 8bpp SVGA graphics modes */
-    case 0x5d:
-    case 0x5e:
-    case 0x62:
-      if (snap_X) {
-        /* win31 cursor snap kludge, we temporary force the DOS cursor to the
-         * upper left corner (0,0). If we after that release snapping,
-         * normal X-events will move the cursor to the exact position. (Hans)
-         */
-        x=-127;
-        y=-127;
-        snap_X--;
-      }
-#ifndef MOUSE_SCALE_X
-      x *= 8;  /* these scalings make DeluxePaintIIe operation perfect - */
-      y *= 8;  /*  I don't know about anything else... */
-      dx = (x - mouse.x) >> 3;
-      dy = (y - mouse.y) >> 3;
-#else
-      /* Dos expects 640x200 mouse coordinates! only in this videomode */
-      /* Some games don't... */
-      x = (MOUSE_SCALE_X * x * x_res) / w_x_res;
-      y = (MOUSE_SCALE_Y * y * y_res) / w_y_res;
-      dx = x - mouse.x;
-      dy = y - mouse.y;
-#endif
-      break;
-
-    default:
-      X_printf("set_mouse_position: Invalid video mode 0x%02x\n",video_mode);
-    }
-
-  if (dx || dy)
-    {
-      mouse.mickeyx += dx;
-      mouse.mickeyy += dy;
-      mouse.x=x; 
-      mouse.y=y;
-      mouse_move();
-   }
-
-#else /* NEW_X_MOUSE */
-
-  int dx = 0, dy = 0, x0 = x, y0 = y;
-  int center_x = w_x_res >> 1, center_y = w_y_res >> 1;
-  int move_it = 0;
-
-  if(grab_active && vga.mode_class == GRAPH) {
-    if(x == center_x && y == center_y) return;	/* assume pointer warp event */
-    x = x - center_x + mouse_x;
-    y = y - center_y + mouse_y;
-    x0 = x; y0 = y;
-    XWarpPointer(display, None, mainwindow, 0, 0, 0, 0, center_x, center_y);
+  int x0 = x, y0 = y;
+  if (grab_active) {
+	  int center_x = w_x_res >> 1, center_y = w_y_res >> 1;
+	  int dx = 0, dy = 0;
+	  if (x == center_x && y == center_y) return;  /* assume pointer warp event */
+	  x = x - center_x + mouse_x;
+	  y = y - center_y + mouse_y;
+	  x0 = x;
+	  y0 = y;
+	  XWarpPointer(display, None, mainwindow, 0, 0, 0, 0, center_x, center_y);
+	  dx = x - mouse_x;
+	  dy = y - mouse_y;
+	  mouse_move_relative(dx, dy);
+  } else if (snap_X) {
+	  /*
+	   * win31 cursor snap kludge, we temporary force the DOS cursor to the
+	   * upper left corner (0,0). If we after that release snapping,
+	   * normal X-events will move the cursor to the exact position. (Hans)
+	   */
+	  int dx = 0, dy = 0;
+	  x0 = y0 = 0;
+	  dx = -3 * x_res; dy = -3 * y_res;		/* enough ??? -- sw */
+	  mouse_move_relative(dx, dy);
+	  snap_X--;
+  } else {
+	  mouse_move_absolute(x, y, w_x_res, w_y_res);
   }
-
-  if(vga.mode_class == TEXT) {
-    dx = ((x - mouse_x) * font_width) >> 3;
-    dy = ((y - mouse_y) * font_height) >> 3;
-    x = x * 8 / font_width;
-    y = y * 8 / font_height;
-    if(mouse.x != x || mouse.y != y || dx || dy) move_it = 1;
-    mouse.x = x;
-    mouse.y = y;
-    mouse.mickeyx += dx;
-    mouse.mickeyy += dy;
-  }
-  
-  if(vga.mode_class == GRAPH) {
-
-    if(grab_active) {
-      dx = x - mouse_x;
-      dy = y - mouse_y;
-      mouse.x += dx; mouse.y += dy;
-    }
-    else {
-      if(snap_X) {
-        /*
-         * win31 cursor snap kludge, we temporary force the DOS cursor to the
-         * upper left corner (0,0). If we after that release snapping,
-         * normal X-events will move the cursor to the exact position. (Hans)
-         */
-        mouse.x = mouse.y = 0;
-        x0 = y0 = 0;
-        dx = -3 * x_res; dy = -3 * y_res;		// enough ??? -- sw
-        snap_X--;
-      }
-      else {
-        x = (x * x_res) / w_x_res;
-        y = (y * y_res) / w_y_res;
-        dx = x - (mouse_x * x_res) / w_x_res;
-        dy = y - (mouse_y * y_res) / w_y_res;
-        if(x_res == 320) x <<= 1;		/* 320 -> 640 cf. mouse.c -- 1998/02/22 sw */
-        if(mouse.x != x || mouse.y != y) move_it = 1;
-        mouse.x = x; mouse.y = y;
-      }
-    }
-
-    mouse.mickeyx += dx;
-    mouse.mickeyy += dy;
-    if(dx || dy) move_it = 1;
-    /* fprintf(stderr, "X: mouse.x = %d(X %d), mouse.y = %d(X %d), dx = %d, dy = %d\n", mouse.x, x, mouse.y, y, dx, dy); */
-  }
-
-  if(move_it) mouse_move();
-
   mouse_x = x0;
   mouse_y = y0;
-#endif /* NEW_X_MOUSE */
 }
 
 static void set_mouse_buttons(int state) 
 {
-   mouse.oldlbutton=mouse.lbutton;
-   mouse.oldmbutton=mouse.mbutton;
-   mouse.oldrbutton=mouse.rbutton;
-   mouse.lbutton = ((state & Button1Mask) != 0);
-   mouse.mbutton = ((state & Button2Mask) != 0);
-   mouse.rbutton = ((state & Button3Mask) != 0);
-  if (mouse.lbutton != mouse.oldlbutton) 
-    mouse_lb();
-
-  if (mouse.threebuttons && mouse.mbutton!=mouse.oldmbutton) 
-    mouse_mb();
-
-  if (mouse.rbutton != mouse.oldrbutton) 
-    mouse_rb();
+   mouse_move_buttons(state&Button1Mask, state&Button2Mask, state&Button3Mask);
 }
 #endif /* CONFIG_X_MOUSE */
 
@@ -2581,7 +2494,18 @@ static void send_selection(Time time, Window requestor, Atom target, Atom proper
 	  sel_text_latin[i] = 0xa6;
 	  break;
 	case 0x80 ... 0xff: 
-	  sel_text_latin[i]=dos_to_latin[sel_text_latin[i] - 0x80];
+          switch (config.term_charset) {
+             case CHARSET_LATIN1:
+                sel_text_latin[i]=dos_to_latin1[sel_text_latin[i] - 0x80];
+                break;
+             case CHARSET_LATIN2:
+                sel_text_latin[i]=dos_to_latin2[sel_text_latin[i] - 0x80];
+                break;
+             case CHARSET_LATIN:
+             default:
+                sel_text_latin[i]=dos_to_latin[sel_text_latin[i] - 0x80];
+                break;
+          }
 	} 
     X_printf("X: selection (latin): %s\n",sel_text_latin);  
     XChangeProperty(display, requestor, property, target, 8, PropModeReplace, 
@@ -2764,24 +2688,6 @@ void X_handle_events(void)
     /* Keyboard events */
 
 	case KeyPress:
-#ifndef NEW_X_MOUSE
-#ifdef ENABLE_POINTER_GRAB
-          if(e.xkey.keycode == 96) { /* terrible hack, is F12 -- sw */
-            if(grab_active ^= 1) {
-              X_printf("X: grab activated\n");
-              XGrabKeyboard(display, mainwindow, True, GrabModeAsync, GrabModeAsync, CurrentTime);
-              XGrabPointer(display, mainwindow, True, PointerMotionMask | ButtonPressMask | ButtonReleaseMask,
-                GrabModeAsync, GrabModeAsync, None,  None, CurrentTime);
-            }
-            else {
-              X_printf("X: grab released\n");
-              XUngrabPointer(display, CurrentTime);
-              XUngrabKeyboard(display, CurrentTime);
-            }
-            break;
-          }
-#endif
-#else /* NEW_X_MOUSE */
           if((e.xkey.state & ControlMask) && (e.xkey.state & Mod1Mask) && grab_keysym != NoSymbol)
             if(XKeycodeToKeysym(display, e.xkey.keycode, 0) == grab_keysym) {
               if(grab_active ^= 1) {
@@ -2801,7 +2707,6 @@ void X_handle_events(void)
               }
               break;
             }
-#endif /* NEW_X_MOUSE */
 
 	case KeyRelease:
 /* 
@@ -2867,14 +2772,7 @@ void X_handle_events(void)
 	   * drawn by win31 and align it with the X-cursor.
 	   * (Hans)
 	   */
-#ifndef NEW_X_MOUSE
-#ifdef ENABLE_POINTER_GRAB
-	  if(!grab_active)
-#endif
-	    snap_X=3;
-#else /* NEW_X_MOUSE */
 	  if(!grab_active) snap_X=3;
-#endif /* NEW_X_MOUSE */
 	  X_printf("X: Mouse entering window\n");
 	  set_mouse_position(e.xcrossing.x, e.xcrossing.y);
 	  set_mouse_buttons(e.xcrossing.state);
