@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 #include <stdio.h>
 #include <string.h>
 #include <fcntl.h>
@@ -45,7 +51,7 @@ console_update_cursor(int xpos, int ypos, int blinkflag, int forceflag)
   }
 
   /* The cursor is off-screen, so disable its blinking */
-  if ((unsigned) xpos > co || (unsigned) ypos > li)
+  if ((unsigned) xpos >= co || (unsigned) ypos >= li)
     blinkflag = 0;
   
   if (blinkflag) {
