@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 #ifndef DOSEMU_DEBUG_H
 #define DOSEMU_DEBUG_H
 
@@ -48,9 +54,6 @@ struct debug_flags {
    pd,			/* Packet driver     "P" */
    request,		/* PIC               "r" */
    sound 		/* SOUND	     "S" */
-#ifdef X86_EMULATOR
-   ,emu			/* CPU emulation     "e" */
-#endif
    ;
 };
 
@@ -113,9 +116,6 @@ void verror(const char *fmt, va_list args);
 #define pd_printf(f,a...)       ifprintf(d.pd,f,##a)	   /* pktdrvr */
 #define r_printf(f,a...)        ifprintf(d.request,f,##a)
 #define S_printf(f,a...)     	ifprintf(d.sound,f,##a)
-#ifdef X86_EMULATOR
-#define e_printf(f,a...)     	ifprintf(d.emu,f,##a)
-#endif
 
 #define ALL_DEBUG_ON	memset(&d,9,sizeof(d))
 #define ALL_DEBUG_OFF	memset(&d,0,sizeof(d))
