@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* dos emulator, Matthias Lautner 
  * Extensions by Robert Sanders, 1992-93
  *
@@ -60,7 +66,6 @@ EXTERN char *cstack[16384];
 /* this is DEBUGGING code! */
 EXTERN int sizes INIT(0);
 
-EXTERN char *tmpdir;
 EXTERN int screen, screen_mode;
 
 /* number of highest vid page - 1 */
@@ -130,11 +135,7 @@ void getKeys(void);
 
      int set_ioperm(int, int, int);
 
-#ifdef X86_EMULATOR
-EXTERN struct debug_flags d INIT({0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0});
-#else
 EXTERN struct debug_flags d INIT({0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0});
-#endif
  
 EXTERN u_char in_sighandler, in_ioctl;
 /* one-entry queue ;-( for ioctl's */
@@ -218,10 +219,6 @@ typedef struct vesamode_type_struct {
      typedef struct config_info {
        int hdiskboot;
 
-#ifdef X86_EMULATOR
-       boolean cpuemu;
-       int emuspeed;
-#endif
        /* for video */
        boolean console;
        boolean console_video;
