@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 
 #ifndef _EMU_KEYB_CLNT_H
 #define _EMU_KEYB_CLNT_H
@@ -8,7 +14,9 @@
 
 /* ASCII 0x20..0x7E */
 extern const Bit8u ascii_keys[];
+extern const u_char latin_to_dos[];
 extern const u_char latin1_to_dos[];
+extern const u_char latin2_to_dos[];
 
 int keyb_client_init();
 void keyb_client_close();
