@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /*
  * include/keymaps.h - This file contains prototypes for all
  *                     implemented keyboard-layouts.
@@ -8,9 +14,6 @@
 
 #include "emu.h"
 
-#define KEYMAP_LOAD_BASE_PATH "/var/lib/dosemu/"
-#define KEYMAP_DIR "keymap/"
-
 /* Keyboard-Layout for the alphanumeric part of the keyboard */
 
 #define KEYB_FINNISH           0
@@ -42,6 +45,7 @@
 #define KEYB_USER	      26
 #define NUM_KEYB	      27
 #define KEYB_JP106	      28
+#define KEYB_PL               29
 
 #define CONST
 
@@ -62,11 +66,13 @@ extern unsigned char alt_map_us[];
 #define DEAD_ABOVERING     8
 #define DEAD_DOUBLEACUTE   10
 #define DEAD_CEDILLA       11
-#define DEAD_IOTA          12
+#define DEAD_IOTA          12 
+#define DEAD_OGONEK        14
+#define DEAD_CARON         15
 
 #define FULL_DEADKEY_LIST  DEAD_GRAVE, DEAD_ACUTE, DEAD_CIRCUMFLEX, \
   DEAD_TILDE, DEAD_BREVE, DEAD_ABOVEDOT, DEAD_DIAERESIS, DEAD_ABOVERING, \
-  DEAD_DOUBLEACUTE, DEAD_CEDILLA, DEAD_IOTA
+  DEAD_DOUBLEACUTE, DEAD_CEDILLA, DEAD_IOTA, DEAD_OGONEK, DEAD_CARON
 
 struct dos_dead_key {
   unsigned char d_key;
