@@ -1,3 +1,9 @@
+/* 
+ * (C) Copyright 1992, ..., 1998 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 /* mouse support for dosemu 0.48p2+
  *     Robert Sanders, gt8134b@prism.gatech.edu
  */
@@ -149,4 +155,8 @@ extern void DOSEMUMouseEvents(void);
 
 extern void mouse_event(void);
 
+extern void mouse_move_buttons(int lbutton, int mbutton, int rbutton);
+extern void mouse_move_relative(int dx, int dy);
+extern void mouse_move_absolute(int x, int y, int x_range, int y_range);
+
 #endif /* MOUSE_H */
